mailr26420 - /branches/frame_order_cleanup/lib/frame_order/iso_cone.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 02, 2014 - 22:15:
Author: bugman
Date: Sun Nov  2 22:14:59 2014
New Revision: 26420

URL: http://svn.gna.org/viewcvs/relax?rev=26420&view=rev
Log:
Docstring fixes for the new compile_1st_matrix_iso_cone() function.

Modified:
    branches/frame_order_cleanup/lib/frame_order/iso_cone.py

Modified: branches/frame_order_cleanup/lib/frame_order/iso_cone.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_cleanup/lib/frame_order/iso_cone.py?rev=26420&r1=26419&r2=26420&view=diff
==============================================================================
--- branches/frame_order_cleanup/lib/frame_order/iso_cone.py    (original)
+++ branches/frame_order_cleanup/lib/frame_order/iso_cone.py    Sun Nov  2 
22:14:59 2014
@@ -35,12 +35,14 @@
 
 
 def compile_1st_matrix_iso_cone(matrix, R_eigen, cone_theta, sigma_max):
     """Generate the 1st degree Frame Order matrix for the rotor model.
 
     @param matrix:      The Frame Order matrix, 1st degree to be populated.
     @type matrix:       numpy 3D, rank-2 array
     @param R_eigen:     The eigenframe rotation matrix.
     @type R_eigen:      numpy 3D, rank-2 array
+    @param cone_theta:  The cone opening angle.
+    @type cone_theta:   float
     @param sigma_max:   The maximum torsion angle.
     @type sigma_max:    float
     """
@@ -35,12 +35,14 @@
 
 def compile_1st_matrix_iso_cone(matrix, R_eigen, cone_theta, sigma_max):
-    """Generate the 1st degree Frame Order matrix for the rotor model.
+    """Generate the 1st degree Frame Order matrix for the isotropic cone.
 
     @param matrix:      The Frame Order matrix, 1st degree to be populated.




Related Messages


Powered by MHonArc, Updated Sun Nov 02 23:00:02 2014